@@ -210,7 +210,7 @@ def format_money(amount, rjust=None):
 token_length = 10
 token_chars = string.ascii_letters + string.digits
 def magic_token(length=token_length):
-    return random.choice(string.ascii_letters) + functools.reduce(lambda x, y: x + random.choice(token_chars), range(length-1), '').lower()
+    return random.choice(string.ascii_lowercase) + functools.reduce(lambda x, y: x + random.choice(token_chars), range(length-1), '').lower()
 
 def validate_token(row_id, token):
     return validate_int(row_id) and len([ch for ch in token if ch in token_chars]) == token_length
