@@ -76,8 +76,7 @@ class AegisHandler(tornado.web.RequestHandler):
         self.tmpl['request_name'] = self.page_name = '%s.%s' % (self.__class__.__name__, self.request.method)
         self.tmpl['next_url'] = self.get_next_url()
         self.request.args = dict([(key, self.get_argument(key, strip=False)) for key, val in self.request.arguments.items()])
-        if aegis.config.get('pg_database') or aegis.config.get('mysql_database'):
-            self.setup_user()
+        self.setup_user()
         super(AegisHandler, self).prepare()
 
     def finish(self, chunk=None):
@@ -94,16 +93,14 @@ class AegisHandler(tornado.web.RequestHandler):
 
     def setup_user(self):
         # Set up user-cookie tracking system, based on user-agent
-        self.tmpl['user'] = {}
         if not self.tmpl['user_agent']:
             self.tmpl['user_agent'] = 'NULL USER AGENT'
         self.tmpl['user_agent_obj'] = user_agents.parse(self.tmpl['user_agent'])
+        if not (aegis.config.get('pg_database') or aegis.config.get('mysql_database')):
+            return
+        self.tmpl['user'] = {}
         user_agent = self.models['UserAgent'].set_user_agent(self.tmpl['user_agent'])
-        user_agents_bot = self.tmpl['user_agent_obj'].is_bot
-        aegis_bot = aegis.stdlib.is_robot(self.tmpl["user_agent"])
-        if user_agents_bot or aegis_bot:
-            if user_agents_bot and aegis_bot:
-                logging.warning("Duplicate robot: %s", self.tmpl['user_agent'])
+        if self.user_is_robot():
             self.models['UserAgent'].set_robot_ind(user_agent['user_agent_id'], True)
             user_agent = self.models['UserAgent'].get_id(user_agent['user_agent_id'])
         # Set up all robots to use the same user_id, based on the user-agent string, and don't bother with cookies.
@@ -130,6 +127,9 @@ class AegisHandler(tornado.web.RequestHandler):
                 self.cookie_set('user', user_ck)
         self.tmpl['user']['user_id'] = user['user_id']
 
+    def user_is_robot(self):
+        return bool(self.tmpl['user_agent_obj'].is_bot or aegis.stdlib.is_robot(self.tmpl['user_agent']))
+
     def render(self, template_name, **kwargs):
         template_path = os.path.join(options.template_path, template_name)
         return super(AegisHandler, self).render(template_path, **kwargs)
@@ -163,6 +163,7 @@ class AegisHandler(tornado.web.RequestHandler):
             hooks = ['debug_chat_hook']
         for hook in hooks:
             hook_url = aegis.config.get(hook)
+            # Call own function? So the client can write custom error messages.
             if hook_url:
                 requests.post(hook_url, json={"text": error_message})
         super(AegisHandler, self)._handle_request_exception(ex)
@@ -469,7 +470,7 @@ class AegisApplication():
             if hasattr(handler, 'json_length'):
                 extra_debug += ' | kb: %4.2f' % (handler.json_length / 1024.0)
             extra_debug = aegis.stdlib.cstr(extra_debug, 'yellow')
-            if handler.tmpl.get('user_agent_obj').is_bot:
+            if handler.user_is_robot():
                 extra_debug += aegis.stdlib.cstr('   BOT', 'blue')
         log_method("%s %d %s %.2fms %s", host, handler.get_status(), handler._request_summary(), request_time, extra_debug)
 
@@ -497,17 +498,21 @@ class WebApplication(AegisApplication, tornado.web.Application):
 class AegisWeb(AegisHandler):
     def prepare(self):
         super(AegisWeb, self).prepare()
-        if not self.is_super_admin():
-            raise tornado.web.HTTPError(403)
         self.tmpl['page_title'] = self.tmpl['request_name'].split('.')[0].replace('Aegis', '')
         self.tmpl['aegis_dir'] = aegis.config.aegis_dir()
         self.tmpl['template_dir'] = os.path.join(self.tmpl['aegis_dir'], 'templates')
 
+    def enforce_admin(self):
+        if not self.is_super_admin():
+            raise tornado.web.HTTPError(403)
+
     def get_template_path(self):
         return self.tmpl.get('template_dir')
 
 class AegisHydraForm(AegisWeb):
+    @tornado.web.authenticated
     def get(self, hydra_type_id=None, *args):
+        self.enforce_admin()
         self.tmpl['errors'] = {}
         hydra_type_id = aegis.stdlib.validate_int(hydra_type_id)
         if hydra_type_id:
@@ -516,7 +521,9 @@ class AegisHydraForm(AegisWeb):
             self.tmpl['hydra_type'] = {}
         return self.render_path("hydra_form.html", **self.tmpl)
 
+    @tornado.web.authenticated
     def post(self, hydra_type_id=None, *args):
+        self.enforce_admin()
         self.logw(self.request.args, "ARGS")
         # Validate Input
         self.tmpl['errors'] = {}
@@ -542,11 +549,15 @@ class AegisHydraForm(AegisWeb):
 
 
 class AegisHydra(AegisWeb):
+    @tornado.web.authenticated
     def get(self, *args):
+        self.enforce_admin()
         self.tmpl['hydra_types'] = aegis.model.HydraType.scan()
         return self.render_path("hydra.html", **self.tmpl)
 
+    @tornado.web.authenticated
     def post(self, *args):
+        self.enforce_admin()
         self.logw(self.request.args, "ARGS")
         pause_ids = [aegis.stdlib.validate_int(k.replace('pause_', '')) for k in self.request.args.keys() if k.startswith('pause_')]
         unpause_ids = [aegis.stdlib.validate_int(k.replace('unpause_', '')) for k in self.request.args.keys() if k.startswith('unpause_')]
@@ -594,12 +605,16 @@ class AegisReportForm(AegisWeb):
         if not self.columns['report_sql']:
             self.tmpl['errors']['report_sql'] = 'Report SQL Required'
 
+    @tornado.web.authenticated
     def get(self, report_type_id=None, *args):
+        self.enforce_admin()
         self.tmpl['errors'] = {}
         self.validate_report_type(report_type_id)
         return self.screen()
 
+    @tornado.web.authenticated
     def post(self, report_type_id=None, *args):
+        self.enforce_admin()
         self.validate_report_type(report_type_id)
         self.validate_input()
         if self.tmpl['errors']:
@@ -631,7 +646,9 @@ class AegisReportForm(AegisWeb):
 
 
 class AegisReport(AegisWeb):
+    @tornado.web.authenticated
     def get(self, report_type_id=None, *args):
+        self.enforce_admin()
         self.tmpl['errors'] = {}
         self.tmpl['column_names'] = []
         if report_type_id:
@@ -665,7 +682,9 @@ class AegisReport(AegisWeb):
 
 
 class AegisHome(AegisWeb):
+    @tornado.web.authenticated    # Could do something like @aegis.webapp.admin_only which also sends for login but then rejects if not admin
     def get(self, *args):
+        self.enforce_admin()
         return self.render_path("index.html", **self.tmpl)
 
 
